Module datasets

Module datasets 

Python bindings for scirs2-datasets

This module provides Python bindings for dataset loading and generation, including toy datasets, synthetic data generators, and utilities.

Functions

register_module
Python module registration