ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 34 variants Computation, Domain, Dispatch, Convergence, Dimension, Shape, Index, Value, Type, NotImplemented, Implementation, Memory, Allocation, Config, InvalidArgument, InvalidInput, Permission, Validation, InvalidState, Jit, Json, Io, Scheduler, Timeout, Compression, InvalidShape, Device, Mutex, Thread, Stream, EndOfStream, Resource, Communication, Security,
}
Lightweight classification of CoreError variants.

Every CoreError variant maps to exactly one ErrorKind. This enum is Copy and suitable for use in match arms, hash maps, etc.

Variants



Computation

Generic computation error



Domain

Input outside valid mathematical domain



Dispatch

Array protocol dispatch failure



Convergence

Algorithm did not converge



Dimension

Array dimension mismatch



Shape

Array shape incompatibility



Index

Index out of bounds



Value

Invalid value



Type

Type mismatch



NotImplemented

Feature not implemented



Implementation

Partial implementation



Memory

Memory allocation failure



Allocation

Allocation-specific error



Config

Configuration error



InvalidArgument

Invalid argument



InvalidInput

Invalid input



Permission

Permission error



Validation

Validation failure



InvalidState

Invalid object state



Jit

JIT compilation error



Json

JSON error



Io

I/O error



Scheduler

Scheduler error



Timeout

Timeout error



Compression

Compression error



InvalidShape

Invalid array shape



Device

GPU/device error



Mutex

Mutex/lock error



Thread

Thread error



Stream

Stream error



EndOfStream

End-of-stream



Resource

Resource error



Communication

Communication error



Security

Security error

Implementations

Source

impl ErrorKind

pub const fn as_str(&self) -> &'static str

Human-readable name of this error kind.

Whether this error kind is related to array shapes or dimensions.

Whether this error kind is related to resource exhaustion.

Whether this error kind is related to I/O or communication.

Whether this error kind is related to concurrency.

pub const fn is_programming_error(&self) -> bool

Whether this error kind indicates a programming error (e.g., invalid argument).

pub const fn is_retryable(&self) -> bool

Whether this error is typically retryable.