Batch/vectorized Python APIs for statistics
Provides batch operations that reduce FFI overhead when calling many small statistical computations from Python.
Functions
- batch_
correlation - Batch Pearson correlation matrix for a list of arrays.
- batch_
descriptive_ stats - Batch descriptive stats for multiple arrays.
- batch_
pdf_ eval - Evaluate the PDF of a named distribution at each data point.
- register_
batch_ module - Register batch stats functions into the Python module.
- stats_
summary - Compute mean, std, and variance in a single batch call.