pub struct Dropout<F>{ /* private fields */ }Expand description
Dropout layer
During training, randomly sets input elements to zero with probability p.
During inference, scales the output by 1/(1-p) to maintain the expected value.
Implementations
Sourceimpl<F> Dropout<F>
impl<F> Dropout<F>
Sourcepub fn new<R>(p: f64, rng: &mut R) -> Result<Dropout<F>, NeuralError>
pub fn new<R>(p: f64, rng: &mut R) -> Result<Dropout<F>, NeuralError>
Create a new dropout layer
Arguments
p- Dropout probability (0.0 to 1.0)rng- Random number generator
Sourcepub fn set_training(&mut self, training: bool)
pub fn set_training(&mut self, training: bool)
Set the training mode In training mode, elements are randomly dropped. In inference mode, all elements are kept but scaled.
Sourcepub fn is_training(&self) -> bool
pub fn is_training(&self) -> bool
Get the training mode