pub fn parallel_map_mean(
py: Python<'_>,
arrays: Vec<Vec<f64>>,
) -> PyResult<Vec<f64>>Expand description
Compute the arithmetic mean of each sub-array in parallel.
The GIL is released during Rayon computation, allowing Python threads to run concurrently.
Empty sub-arrays return 0.0.
Arguments
arrays– list of float arrays, one mean value is produced per element.
Returns
A list of f64 mean values with the same length as arrays.