Module series

Module series 

Python bindings for scirs2-series using PyO3

This module provides Python bindings for seamless integration with pandas, statsmodels, and other Python time series analysis libraries.

Structs

PyARIMA
Python wrapper for ARIMA models
PyTimeSeries
Python wrapper for time series data

Functions

create_pandas_dataframe
Creates a pandas DataFrame from a HashMap of Array1 data
create_pandas_series
Creates a pandas Series from a Rust Array1
register_module
Python module registration