pub fn batch_correlation(arrays: Vec<Vec<f64>>) -> PyResult<Vec<Vec<f64>>>Expand description
Batch Pearson correlation matrix for a list of arrays.
Computes the full correlation matrix for the provided arrays. Entry [i][j] is the Pearson correlation between arrays[i] and arrays[j].
Parameters: arrays: List of arrays (all must have the same length)
Returns:
Correlation matrix as Vec<Vec